Package: biobtreeR
Type: Package
Title: Using biobtree tool from R
Version: 1.25.0
Author: Tamer Gur
Maintainer: Tamer Gur <tgur@ebi.ac.uk>
Description: The biobtreeR package provides an interface to [biobtree](https://github.com/tamerh/biobtree) tool which covers large set of bioinformatics datasets and allows search and chain mappings functionalities.
License: MIT + file LICENSE
Encoding: UTF-8
LazyLoad: yes
NeedsCompilation: no
URL: https://github.com/tamerh/biobtreeR
BugReports: https://github.com/tamerh/biobtreeR/issues
VignetteBuilder: knitr
Suggests: BiocStyle, knitr,testthat,rmarkdown,markdown
Imports: httr, httpuv, stringi,jsonlite,methods,utils
biocViews: Annotation
RoxygenNote: 6.1.1
git_url: https://git.bioconductor.org/packages/biobtreeR
git_branch: devel
git_last_commit: c98ce19
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-28 21:29:54 UTC; biocbuild
