importFrom(httr,HEAD,content,GET)
importFrom(httpuv,encodeURIComponent)
importFrom(jsonlite,fromJSON)
importFrom(stringi,stri_trim)
importFrom(methods, new)
importFrom(utils, download.file, untar, unzip)

export(bbUseOutDir,bbBuiltInDB,bbBuildCustomDB,bbStart,bbStop,bbSearch,bbMapping,bbEntry,bbEntryFilter,bbEntryPage,bbListAttrs,bbListDatasets)
