% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/server.R
\name{bbStop}
\alias{bbStop}
\title{Stop biobtree}
\usage{
bbStop()
}
\value{
returns empty
}
\description{
Stops running background biobtree process which started with \code{bbStart}
}
\examples{
bbStop()
}
