% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/entry.R
\name{bbEntryFilter}
\alias{bbEntryFilter}
\title{Retrieve entry with filtered dataset}
\usage{
bbEntryFilter(identifer, source, filters, page = NULL)
}
\arguments{
\item{identifer}{Identifer for the entry.}

\item{source}{Dataset identifier}

\item{filters}{Comma seperated dataset identifer to retrieve}

\item{page}{Page index if results is more than default biobtree paging size.}
}
\value{
returns biobtree json object
}
\description{
Similar with entry retrieval but filtered mapping entries with given datasets.
}
\examples{


bbStart() # if not already started
bbEntryFilter("HGNC:12009","hgnc","uniprot,ensembl")


}
\author{
Tamer Gur
}
